/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <activemq/connector/openwire/commands/ProducerAck.h>
#include <activemq/exceptions/ActiveMQException.h>
#include <decaf/lang/exceptions/NullPointerException.h>
#include <memory>

using namespace std;
using namespace activemq;
using namespace activemq::exceptions;
using namespace activemq::connector;
using namespace activemq::connector::openwire;
using namespace activemq::connector::openwire::commands;
using namespace decaf::lang::exceptions;

/*
 *
 *  Command and marshaling code for OpenWire format for ProducerAck
 *
 *
 *  NOTE!: This file is autogenerated - do not modify!
 *         if you need to make a change, please see the Java Classes in the
 *         activemq-core module
 *
 */
////////////////////////////////////////////////////////////////////////////////
ProducerAck::ProducerAck()
{
    this->producerId = NULL;
    this->size = 0;
}

////////////////////////////////////////////////////////////////////////////////
ProducerAck::~ProducerAck()
{
    delete this->producerId;
}

////////////////////////////////////////////////////////////////////////////////
ProducerAck* ProducerAck::cloneDataStructure() const {
    std::auto_ptr<ProducerAck> producerAck( new ProducerAck() );

    // Copy the data from the base class or classes
    producerAck->copyDataStructure( this );

    return producerAck.release();
}

////////////////////////////////////////////////////////////////////////////////
void ProducerAck::copyDataStructure( const DataStructure* src ) {

    // Copy the data of the base class or classes
    BaseCommand<transport::Command>::copyDataStructure( src );

    const ProducerAck* srcPtr = dynamic_cast<const ProducerAck*>( src );

    if( srcPtr == NULL || src == NULL ) {

        throw decaf::lang::exceptions::NullPointerException(
            __FILE__, __LINE__,
            "ProducerAck::copyDataStructure - src is NULL or invalid" );
    }
    if( srcPtr->getProducerId() != NULL ) {
        this->setProducerId(
            dynamic_cast<ProducerId*>(
                srcPtr->getProducerId()->cloneDataStructure() ) );
    }
    this->setSize( srcPtr->getSize() );
}

////////////////////////////////////////////////////////////////////////////////
unsigned char ProducerAck::getDataStructureType() const {
    return ProducerAck::ID_PRODUCERACK;
}

////////////////////////////////////////////////////////////////////////////////
std::string ProducerAck::toString() const {

    ostringstream stream;

    stream << "Begin Class = ProducerAck" << std::endl;
    stream << " Value of ProducerAck::ID_PRODUCERACK = 19" << std::endl;
    stream << " Value of ProducerId is Below:" << std::endl;
    if( this->getProducerId() != NULL ) {
        stream << this->getProducerId()->toString() << std::endl;
    } else {
        stream << "   Object is NULL" << std::endl;
    }
    stream << " Value of Size = " << this->getSize() << std::endl;
    stream << BaseCommand<transport::Command>::toString();
    stream << "End Class = ProducerAck" << std::endl;

    return stream.str();
}

////////////////////////////////////////////////////////////////////////////////
bool ProducerAck::equals( const DataStructure* value ) const {
    const ProducerAck* valuePtr = dynamic_cast<const ProducerAck*>( value );

    if( valuePtr == NULL || value == NULL ) {
        return false;
    }
    if( this->getProducerId() != NULL ) {
        if( !this->getProducerId()->equals( valuePtr->getProducerId() ) ) {
            return false;
        }
    } else if( valuePtr->getProducerId() != NULL ) {
        return false;
    }
    if( this->getSize() != valuePtr->getSize() ) {
        return false;
    }
    if( !BaseCommand<transport::Command>::equals( value ) ) {
        return false;
    }
    return true;
}

////////////////////////////////////////////////////////////////////////////////
const ProducerId* ProducerAck::getProducerId() const {
    return producerId;
}

////////////////////////////////////////////////////////////////////////////////
ProducerId* ProducerAck::getProducerId() {
    return producerId;
}

////////////////////////////////////////////////////////////////////////////////
void ProducerAck::setProducerId(ProducerId* producerId ) {
    this->producerId = producerId;
}

////////////////////////////////////////////////////////////////////////////////
int ProducerAck::getSize() const {
    return size;
}

////////////////////////////////////////////////////////////////////////////////
void ProducerAck::setSize(int size ) {
    this->size = size;
}

